function isArray (any) {
  return Array.isArray(any)
}

function isObject (any) {
  return any !== null && typeof (any) === 'object'
}





var ErrorBag = function ErrorBag (errors) {
  this._errors = typeof (errors) === 'object' ? errors : {};
};

ErrorBag.prototype.has = function has (key) {
  return this._errors.hasOwnProperty(key)
};

ErrorBag.prototype.get = function get (key) {
  var value = this._errors[key];

  if (isArray(value)) {
    return value.join(' ')
  }

  return value
};

ErrorBag.prototype.unset = function unset (key) {
  delete this._errors[key];
};

var formHelper = {

  provide: function provide () {
    var this$1 = this;

    var form = {};

    Object.defineProperties(form, {
      status: {
        enumerable: true,
        get: function () { return this$1.$data._formStatus; }
      },

      errors: {
        enumerable: true,
        get: function () { return this$1.$data._formErrors; }
      }
    });

    return { form: form }
  },

  data: function () { return ({ _formErrors: null, _formStatus: null }); },

  methods: {

    /**
     * @deprecated
     */
    setErrors: function setErrors (payload) {
      return this.setFormErrors(payload)
    },

    /**
     * @deprecated
     */
    clearError: function clearError (key) {
      return this.clearFormErrors(key)
    },

    setFormErrors: function setFormErrors (payload) {
      this.clearFormErrors();

      if (!isObject(payload)) { return }

      this.$data._formErrors = new ErrorBag(payload);
      if ('$message' in payload) {
        this.$data._formStatus = payload.$message;
      }
    },

    setFormStatus: function setFormStatus (status) {
      this.$data._formStatus = status;
    },

    clearFormErrors: function clearFormErrors (key) {
      if (key !== undefined) {
        this.$data._formErrors.unset(key);
      } else {
        this.$data._formErrors = new ErrorBag({});
        this.$data._formStatus = null;
      }
    }

  },

  created: function created () {
    this.$data._formErrors = new ErrorBag({});
  }
};

var inputHelper = {
  inject: ['form'],

  props: {
    value: { required: true },
    title: { type: String, default: null },
    subtitle: { type: String, default: null },
    name: { type: String, default: null },
    inputName: { type: String, default: null },
    errors: {
      validator: function validator (errors) {
        return !errors || errors instanceof ErrorBag
      },

      default: null
    },
    inputClass: String,
    placeholder: String,
    autofill: [String, Boolean],
    autocomplete: [String, Boolean],
    autofocus: [Boolean],
    min: {},
    max: {}
  },

  data: function () { return ({
    expression: null,
    required: null
  }); },

  computed: {

    id: function id () {
      return ("text" + (this._uid))
    },

    nameKey: function nameKey () {
      var inputName = this.inputName;
      var expression = this.expression;

      if (inputName) { return inputName }

      return expression
    },

    feedback: function feedback () {
      var errors = this.errors;
      var form = this.form;
      var name = this.nameKey;

      if (errors) {
        return errors.get(name)
      }

      if (form && form.errors) {
        return form.errors.get(name)
      }

      return null
    }
  },

  methods: {
    /**
     * Mirror attributes from root element.
     *
     * @return {void}
     */
    updateAttributes: function updateAttributes () {
      if (!this.$vnode || !this.$vnode.data || !this.$vnode.data.attrs) { return }

      this.required = this.$vnode.data.attrs.hasOwnProperty('required');
    }
  },

  mounted: function mounted () {
    var this$1 = this;

    var model = this.$vnode.data.model;

    if (model) {
      this.expression = model.expression.split('.').pop();
    }

    this.updateAttributes();

    if (this.autofocus !== false) {
      this.$nextTick(function () {
        var el = this$1.$el.querySelector('[autofocus]');
        if (el) { el.focus(); }
      });
    }
  },

  beforeUpdate: function beforeUpdate () {
    this.updateAttributes();
  }
};

export { formHelper, inputHelper };
